/****************************************************************************
** ManDVD
**
** Created: Mon May 08 14:00:00 2006
**      by: Gibault Stphane
**	Hacked on by Mikael Bhm micko@bag.org
**
** This is a tool for simply creating DVD Video
** 
****************************************************************************/
//
// C++ Interface: chapter
//
// Description: Headerfile for subtitle managment
//
//
// Author: Mikael Bhm <micko@bag.org>, (C) 2008
//
// Copyright: See COPYING file that comes with this distribution
//
//


#ifndef SUBTITLE_H
#define SUBTITLE_H

#include "mandvd_global.h"
#include <mainfrm.h>
#include <qlabel.h>
#include <qtoolbutton.h>
#include <qbuttongroup.h>
#include <qlineedit.h>
#include <qcombobox.h>
#include <qtextedit.h>
#include <qspinbox.h>
#include <qslider.h>
#include <qcheckbox.h>
#include <qradiobutton.h>
#include <qmessagebox.h>
#include <qlistview.h>
#include <qdatetimeedit.h>
#include <qpushbutton.h>

/* Declarations by Mikael */


#endif